/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.blogger.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Model definition for Blog.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Blogger API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Blog extends GenericJson {

  /**
   * The JSON custom meta-data for the Blog
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String customMetaData;

  /**
   * The description of this blog. This is displayed underneath the title.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * The identifier for this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind of this entry. Always blogger#blog
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The locale this Blog is set to.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Locale locale;

  /**
   * The name of this blog. This is displayed as the title.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * The container of pages in this blog.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Pages pages;

  /**
   * The container of posts in this blog.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Posts posts;

  /**
   * RFC 3339 date-time when this blog was published.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime published;

  /**
   * The API REST URL to fetch this resource from.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * RFC 3339 date-time when this blog was last updated.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime updated;

  /**
   * The URL where this blog is published.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String url;

  /**
   * The JSON custom meta-data for the Blog
   * The value returned may be {@code null}.
   */
  public String getCustomMetaData() {
    return customMetaData;
  }

  /**
   * The JSON custom meta-data for the Blog
   * The value set may be {@code null}.
   */
  public Blog setCustomMetaData(String customMetaData) {
    this.customMetaData = customMetaData;
    return this;
  }

  /**
   * The description of this blog. This is displayed underneath the title.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * The description of this blog. This is displayed underneath the title.
   * The value set may be {@code null}.
   */
  public Blog setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * The identifier for this resource.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The identifier for this resource.
   * The value set may be {@code null}.
   */
  public Blog setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind of this entry. Always blogger#blog
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind of this entry. Always blogger#blog
   * The value set may be {@code null}.
   */
  public Blog setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The locale this Blog is set to.
   * The value returned may be {@code null}.
   */
  public Locale getLocale() {
    return locale;
  }

  /**
   * The locale this Blog is set to.
   * The value set may be {@code null}.
   */
  public Blog setLocale(Locale locale) {
    this.locale = locale;
    return this;
  }

  /**
   * The name of this blog. This is displayed as the title.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * The name of this blog. This is displayed as the title.
   * The value set may be {@code null}.
   */
  public Blog setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * The container of pages in this blog.
   * The value returned may be {@code null}.
   */
  public Pages getPages() {
    return pages;
  }

  /**
   * The container of pages in this blog.
   * The value set may be {@code null}.
   */
  public Blog setPages(Pages pages) {
    this.pages = pages;
    return this;
  }

  /**
   * The container of posts in this blog.
   * The value returned may be {@code null}.
   */
  public Posts getPosts() {
    return posts;
  }

  /**
   * The container of posts in this blog.
   * The value set may be {@code null}.
   */
  public Blog setPosts(Posts posts) {
    this.posts = posts;
    return this;
  }

  /**
   * RFC 3339 date-time when this blog was published.
   * The value returned may be {@code null}.
   */
  public DateTime getPublished() {
    return published;
  }

  /**
   * RFC 3339 date-time when this blog was published.
   * The value set may be {@code null}.
   */
  public Blog setPublished(DateTime published) {
    this.published = published;
    return this;
  }

  /**
   * The API REST URL to fetch this resource from.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * The API REST URL to fetch this resource from.
   * The value set may be {@code null}.
   */
  public Blog setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * RFC 3339 date-time when this blog was last updated.
   * The value returned may be {@code null}.
   */
  public DateTime getUpdated() {
    return updated;
  }

  /**
   * RFC 3339 date-time when this blog was last updated.
   * The value set may be {@code null}.
   */
  public Blog setUpdated(DateTime updated) {
    this.updated = updated;
    return this;
  }

  /**
   * The URL where this blog is published.
   * The value returned may be {@code null}.
   */
  public String getUrl() {
    return url;
  }

  /**
   * The URL where this blog is published.
   * The value set may be {@code null}.
   */
  public Blog setUrl(String url) {
    this.url = url;
    return this;
  }

  /**
   * The locale this Blog is set to.
   */
  public static final class Locale extends GenericJson {

    /**
     * The country this blog's locale is set to.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String country;

    /**
     * The language this blog is authored in.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String language;

    /**
     * The language variant this blog is authored in.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String variant;

    /**
     * The country this blog's locale is set to.
     * The value returned may be {@code null}.
     */
    public String getCountry() {
      return country;
    }

    /**
     * The country this blog's locale is set to.
     * The value set may be {@code null}.
     */
    public Locale setCountry(String country) {
      this.country = country;
      return this;
    }

    /**
     * The language this blog is authored in.
     * The value returned may be {@code null}.
     */
    public String getLanguage() {
      return language;
    }

    /**
     * The language this blog is authored in.
     * The value set may be {@code null}.
     */
    public Locale setLanguage(String language) {
      this.language = language;
      return this;
    }

    /**
     * The language variant this blog is authored in.
     * The value returned may be {@code null}.
     */
    public String getVariant() {
      return variant;
    }

    /**
     * The language variant this blog is authored in.
     * The value set may be {@code null}.
     */
    public Locale setVariant(String variant) {
      this.variant = variant;
      return this;
    }

  }

  /**
   * The container of pages in this blog.
   */
  public static final class Pages extends GenericJson {

    /**
     * The URL of the container for pages in this blog.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String selfLink;

    /**
     * The count of pages in this blog.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer totalItems;

    /**
     * The URL of the container for pages in this blog.
     * The value returned may be {@code null}.
     */
    public String getSelfLink() {
      return selfLink;
    }

    /**
     * The URL of the container for pages in this blog.
     * The value set may be {@code null}.
     */
    public Pages setSelfLink(String selfLink) {
      this.selfLink = selfLink;
      return this;
    }

    /**
     * The count of pages in this blog.
     * The value returned may be {@code null}.
     */
    public Integer getTotalItems() {
      return totalItems;
    }

    /**
     * The count of pages in this blog.
     * The value set may be {@code null}.
     */
    public Pages setTotalItems(Integer totalItems) {
      this.totalItems = totalItems;
      return this;
    }

  }

  /**
   * The container of posts in this blog.
   */
  public static final class Posts extends GenericJson {

    /**
     * The List of Posts for this Blog.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<Post> items;

    static {
      // hack to force ProGuard to consider Post used, since otherwise it would be stripped out
      // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
      com.google.api.client.util.Data.nullOf(Post.class);
    }

    /**
     * The URL of the container for posts in this blog.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String selfLink;

    /**
     * The count of posts in this blog.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer totalItems;

    /**
     * The List of Posts for this Blog.
     * The value returned may be {@code null}.
     */
    public java.util.List<Post> getItems() {
      return items;
    }

    /**
     * The List of Posts for this Blog.
     * The value set may be {@code null}.
     */
    public Posts setItems(java.util.List<Post> items) {
      this.items = items;
      return this;
    }

    /**
     * The URL of the container for posts in this blog.
     * The value returned may be {@code null}.
     */
    public String getSelfLink() {
      return selfLink;
    }

    /**
     * The URL of the container for posts in this blog.
     * The value set may be {@code null}.
     */
    public Posts setSelfLink(String selfLink) {
      this.selfLink = selfLink;
      return this;
    }

    /**
     * The count of posts in this blog.
     * The value returned may be {@code null}.
     */
    public Integer getTotalItems() {
      return totalItems;
    }

    /**
     * The count of posts in this blog.
     * The value set may be {@code null}.
     */
    public Posts setTotalItems(Integer totalItems) {
      this.totalItems = totalItems;
      return this;
    }

  }

}
